Welcome to Smart Farm Hub's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   modules
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. _indexUserDoc:

User Documentation
------------------

Access detailed information about the different features and capabilities
provided by the library and how to use them.

* :doc:`user_doc/LowCostSmartFarmHub_terminology`
* :doc:`user_doc/working_with_rpi_gateway`

.. _indexAPI:

API reference
-------------

The API reference contains more detailed documentation about the API for
developers who are interested in using and extending the library functionality.



.. toctree::
   :maxdepth: 4
   :hidden:
   :caption: User Documentation

   user_doc/LowCostSmartFarmHub_terminology
   user_doc/working_with_rpi_gateway